@@ -1,5 +1,5 @@
+import inspect
 import textwrap
-from inspect import isclass
 
 from .helpers import echo
 
@@ -37,11 +37,10 @@ class HelpMixin:
     @property
     def _commands(self):
         commands = {}
-        for name in dir(self):
-            if name.startswith("_"):
-                continue
+        names = [name for name in self.__dir__() if not name.startswith("_")]
+        for name in names:
             cmd = getattr(self, name, None)
-            if isclass(cmd):
+            if inspect.isclass(cmd):
                 continue
             commands[name] = cmd
         return commands
@@ -49,11 +48,10 @@ class HelpMixin:
     @property
     def _subcommands(self):
         subcommands = {}
-        for name in dir(self):
-            if name.startswith("_"):
-                continue
+        names = [name for name in self.__dir__() if not name.startswith("_")]
+        for name in names:
             cls = getattr(self, name, None)
-            if not isclass(cls):
+            if not inspect.isclass(cls):
                 continue
             subcommands[name] = cls
         return subcommands
@@ -63,17 +61,24 @@ class HelpMixin:
         return INDENT_WITH * self._indent_level
 
     def _help(self, header=True):
+        self._help_intro()
         self._help_header()
         self._help_body()
         print()
 
-    def _help_header(self):
-        if self._intro:
-            intro = textwrap.indent(self._intro.strip(), " ")
+    def _help_intro(self):
+        doc = get_doc(self)
+        if doc:
+            intro = textwrap.indent(doc.strip(), " ")
             echo(f"\n{intro}")
+
+    def _help_header(self):
         echo("\n <fg:yellow>Usage:</fg>")
         echo(f" {self._indent}{self._parent} <command> [args] [options]\n")
-        echo(f" {self._indent}Run any command with the --help option for more information.")
+        echo(
+            f" {self._indent}"
+            "Run any command with the --help option for more information."
+        )
         echo("\n <fg:yellow>Available Commands:</fg>")
 
     def _help_body(self):
@@ -83,7 +88,7 @@ class HelpMixin:
             self._help_list_subcommand(name, cls)
 
     def _help_list_subcommand(self, name, cls):
-        echo(f" {self._indent}<fg:cyan>{name.ljust(COL_SIZE)}</fg>")
+        echo(f"\n {self._indent}<fg:cyan>{name.ljust(COL_SIZE)}</fg>")
         cli = self._init_subcommand(name, cls, indent_level=self._indent_level + 1)
         cli._help_body()
 
